@@ -61,7 +61,7 @@ int plugin_init(desc)
  struct arglist * desc;
 { 
  plug_set_id(desc, 10330);
- plug_set_version(desc, "$Revision: 1.225 $");
+ plug_set_version(desc, "$Revision: 1.228 $");
  
  plug_set_name(desc, FR_NAME, "francais");
  plug_set_name(desc, EN_NAME, NULL);
@@ -1849,6 +1849,8 @@ static int plugin_do_run(desc, h, test_ssl)
 #ifdef DEBUG
 	fprintf(stderr, "Banner is unknown on port %d - connecting...\n", port);
 #endif
+	if (banner != NULL)
+	  efree (&banner);
 	banner = NULL;
 	if (test_ssl == 2 || 
 	    (test_ssl == 1 && known_ssl_port(port)))
@@ -2413,6 +2415,7 @@ static void sigterm(int s)
  {
   if(sons[i] != 0)kill(sons[i], SIGTERM);
  }
+ _exit(0);
 }
 
 static void sigchld(int s)
@@ -2671,7 +2674,10 @@ int plugin_run(desc)
     plugin_do_run(desc, sons_args[i], test_ssl);
     exit(0);
    }
-   else close(sons_pipe[i][0]);
+   else {
+	close(sons_pipe[i][0]);
+	if ( sons[i] < 0 ) sons[i] = 0; /* Fork failed */
+	}
   }
  }
  
